# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_metadata import DocMetadata  # noqa: F401,E501


class CheckAvailabilityRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'trace_id': 'str',
        'in_doc_metadata': 'DocMetadata',
        'status': 'bool'
    }

    attribute_map = {
        'trace_id': 'traceId',
        'in_doc_metadata': 'inDocMetadata',
        'status': 'Status'
    }

    def __init__(self, trace_id=None, in_doc_metadata=None, status=None):  # noqa: E501
        """CheckAvailabilityRes - a model defined in Swagger"""  # noqa: E501

        self._trace_id = None
        self._in_doc_metadata = None
        self._status = None
        self.discriminator = None

        if trace_id is not None:
            self.trace_id = trace_id
        if in_doc_metadata is not None:
            self.in_doc_metadata = in_doc_metadata
        if status is not None:
            self.status = status

    @property
    def trace_id(self):
        """Gets the trace_id of this CheckAvailabilityRes.  # noqa: E501


        :return: The trace_id of this CheckAvailabilityRes.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this CheckAvailabilityRes.


        :param trace_id: The trace_id of this CheckAvailabilityRes.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def in_doc_metadata(self):
        """Gets the in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501


        :return: The in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._in_doc_metadata

    @in_doc_metadata.setter
    def in_doc_metadata(self, in_doc_metadata):
        """Sets the in_doc_metadata of this CheckAvailabilityRes.


        :param in_doc_metadata: The in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501
        :type: DocMetadata
        """

        self._in_doc_metadata = in_doc_metadata

    @property
    def status(self):
        """Gets the status of this CheckAvailabilityRes.  # noqa: E501


        :return: The status of this CheckAvailabilityRes.  # noqa: E501
        :rtype: bool
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckAvailabilityRes.


        :param status: The status of this CheckAvailabilityRes.  # noqa: E501
        :type: bool
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CheckAvailabilityRes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckAvailabilityRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
