# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.pdf_validation_event import PdfValidationEvent  # noqa: F401,E501


class PdfValidation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'validations': 'list[PdfValidationEvent]',
        'conformance_codes': 'list[str]',
        'error_code': 'str',
        'error_message': 'str'
    }

    attribute_map = {
        'validations': 'validations',
        'conformance_codes': 'conformanceCodes',
        'error_code': 'errorCode',
        'error_message': 'errorMessage'
    }

    def __init__(self, validations=None, conformance_codes=None, error_code=None, error_message=None):  # noqa: E501
        """PdfValidation - a model defined in Swagger"""  # noqa: E501

        self._validations = None
        self._conformance_codes = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if validations is not None:
            self.validations = validations
        if conformance_codes is not None:
            self.conformance_codes = conformance_codes
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def validations(self):
        """Gets the validations of this PdfValidation.  # noqa: E501


        :return: The validations of this PdfValidation.  # noqa: E501
        :rtype: list[PdfValidationEvent]
        """
        return self._validations

    @validations.setter
    def validations(self, validations):
        """Sets the validations of this PdfValidation.


        :param validations: The validations of this PdfValidation.  # noqa: E501
        :type: list[PdfValidationEvent]
        """

        self._validations = validations

    @property
    def conformance_codes(self):
        """Gets the conformance_codes of this PdfValidation.  # noqa: E501


        :return: The conformance_codes of this PdfValidation.  # noqa: E501
        :rtype: list[str]
        """
        return self._conformance_codes

    @conformance_codes.setter
    def conformance_codes(self, conformance_codes):
        """Sets the conformance_codes of this PdfValidation.


        :param conformance_codes: The conformance_codes of this PdfValidation.  # noqa: E501
        :type: list[str]
        """

        self._conformance_codes = conformance_codes

    @property
    def error_code(self):
        """Gets the error_code of this PdfValidation.  # noqa: E501


        :return: The error_code of this PdfValidation.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this PdfValidation.


        :param error_code: The error_code of this PdfValidation.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this PdfValidation.  # noqa: E501


        :return: The error_message of this PdfValidation.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this PdfValidation.


        :param error_message: The error_message of this PdfValidation.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfValidation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfValidation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
