# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StorageFolder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'storage_type': 'str',
        'folder_name': 'str',
        'host': 'str'
    }

    attribute_map = {
        'storage_type': 'storageType',
        'folder_name': 'folderName',
        'host': 'host'
    }

    def __init__(self, storage_type=None, folder_name=None, host=None):  # noqa: E501
        """StorageFolder - a model defined in Swagger"""  # noqa: E501

        self._storage_type = None
        self._folder_name = None
        self._host = None
        self.discriminator = None

        if storage_type is not None:
            self.storage_type = storage_type
        if folder_name is not None:
            self.folder_name = folder_name
        if host is not None:
            self.host = host

    @property
    def storage_type(self):
        """Gets the storage_type of this StorageFolder.  # noqa: E501


        :return: The storage_type of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this StorageFolder.


        :param storage_type: The storage_type of this StorageFolder.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "localSystem"]  # noqa: E501
        if storage_type not in allowed_values:
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    @property
    def folder_name(self):
        """Gets the folder_name of this StorageFolder.  # noqa: E501


        :return: The folder_name of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._folder_name

    @folder_name.setter
    def folder_name(self, folder_name):
        """Sets the folder_name of this StorageFolder.


        :param folder_name: The folder_name of this StorageFolder.  # noqa: E501
        :type: str
        """

        self._folder_name = folder_name

    @property
    def host(self):
        """Gets the host of this StorageFolder.  # noqa: E501


        :return: The host of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this StorageFolder.


        :param host: The host of this StorageFolder.  # noqa: E501
        :type: str
        """

        self._host = host

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StorageFolder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageFolder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
