# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExecutionTrigger(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_time': 'datetime',
        'cron_trigger': 'str',
        'continues': 'bool'
    }

    attribute_map = {
        'start_time': 'startTime',
        'cron_trigger': 'cronTrigger',
        'continues': 'continues'
    }

    def __init__(self, start_time=None, cron_trigger=None, continues=None):  # noqa: E501
        """ExecutionTrigger - a model defined in Swagger"""  # noqa: E501

        self._start_time = None
        self._cron_trigger = None
        self._continues = None
        self.discriminator = None

        if start_time is not None:
            self.start_time = start_time
        if cron_trigger is not None:
            self.cron_trigger = cron_trigger
        if continues is not None:
            self.continues = continues

    @property
    def start_time(self):
        """Gets the start_time of this ExecutionTrigger.  # noqa: E501


        :return: The start_time of this ExecutionTrigger.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ExecutionTrigger.


        :param start_time: The start_time of this ExecutionTrigger.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def cron_trigger(self):
        """Gets the cron_trigger of this ExecutionTrigger.  # noqa: E501


        :return: The cron_trigger of this ExecutionTrigger.  # noqa: E501
        :rtype: str
        """
        return self._cron_trigger

    @cron_trigger.setter
    def cron_trigger(self, cron_trigger):
        """Sets the cron_trigger of this ExecutionTrigger.


        :param cron_trigger: The cron_trigger of this ExecutionTrigger.  # noqa: E501
        :type: str
        """

        self._cron_trigger = cron_trigger

    @property
    def continues(self):
        """Gets the continues of this ExecutionTrigger.  # noqa: E501


        :return: The continues of this ExecutionTrigger.  # noqa: E501
        :rtype: bool
        """
        return self._continues

    @continues.setter
    def continues(self, continues):
        """Sets the continues of this ExecutionTrigger.


        :param continues: The continues of this ExecutionTrigger.  # noqa: E501
        :type: bool
        """

        self._continues = continues

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExecutionTrigger, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecutionTrigger):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
