# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SplitAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'split_after_page': 'int',
        'split_sequence': 'list[int]',
        'recurring_split_after_page': 'int',
        'barcode_starts_with': 'str'
    }

    attribute_map = {
        'split_after_page': 'splitAfterPage',
        'split_sequence': 'splitSequence',
        'recurring_split_after_page': 'recurringSplitAfterPage',
        'barcode_starts_with': 'barcodeStartsWith'
    }

    def __init__(self, split_after_page=None, split_sequence=None, recurring_split_after_page=None, barcode_starts_with=None):  # noqa: E501
        """SplitAction - a model defined in Swagger"""  # noqa: E501

        self._split_after_page = None
        self._split_sequence = None
        self._recurring_split_after_page = None
        self._barcode_starts_with = None
        self.discriminator = None

        if split_after_page is not None:
            self.split_after_page = split_after_page
        if split_sequence is not None:
            self.split_sequence = split_sequence
        if recurring_split_after_page is not None:
            self.recurring_split_after_page = recurring_split_after_page
        if barcode_starts_with is not None:
            self.barcode_starts_with = barcode_starts_with

    @property
    def split_after_page(self):
        """Gets the split_after_page of this SplitAction.  # noqa: E501


        :return: The split_after_page of this SplitAction.  # noqa: E501
        :rtype: int
        """
        return self._split_after_page

    @split_after_page.setter
    def split_after_page(self, split_after_page):
        """Sets the split_after_page of this SplitAction.


        :param split_after_page: The split_after_page of this SplitAction.  # noqa: E501
        :type: int
        """

        self._split_after_page = split_after_page

    @property
    def split_sequence(self):
        """Gets the split_sequence of this SplitAction.  # noqa: E501


        :return: The split_sequence of this SplitAction.  # noqa: E501
        :rtype: list[int]
        """
        return self._split_sequence

    @split_sequence.setter
    def split_sequence(self, split_sequence):
        """Sets the split_sequence of this SplitAction.


        :param split_sequence: The split_sequence of this SplitAction.  # noqa: E501
        :type: list[int]
        """

        self._split_sequence = split_sequence

    @property
    def recurring_split_after_page(self):
        """Gets the recurring_split_after_page of this SplitAction.  # noqa: E501


        :return: The recurring_split_after_page of this SplitAction.  # noqa: E501
        :rtype: int
        """
        return self._recurring_split_after_page

    @recurring_split_after_page.setter
    def recurring_split_after_page(self, recurring_split_after_page):
        """Sets the recurring_split_after_page of this SplitAction.


        :param recurring_split_after_page: The recurring_split_after_page of this SplitAction.  # noqa: E501
        :type: int
        """

        self._recurring_split_after_page = recurring_split_after_page

    @property
    def barcode_starts_with(self):
        """Gets the barcode_starts_with of this SplitAction.  # noqa: E501


        :return: The barcode_starts_with of this SplitAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_starts_with

    @barcode_starts_with.setter
    def barcode_starts_with(self, barcode_starts_with):
        """Sets the barcode_starts_with of this SplitAction.


        :param barcode_starts_with: The barcode_starts_with of this SplitAction.  # noqa: E501
        :type: str
        """

        self._barcode_starts_with = barcode_starts_with

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SplitAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplitAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
