# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.action_flow import ActionFlow  # noqa: F401,E501
from pdf4me.model.execution_trigger import ExecutionTrigger  # noqa: F401,E501
from pdf4me.model.storage_folder import StorageFolder  # noqa: F401,E501


class JobConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_config_id': 'str',
        'enabled': 'bool',
        'active': 'bool',
        'creation_date': 'datetime',
        'mod_date': 'datetime',
        'name': 'str',
        'user_id': 'str',
        'tenant_id': 'str',
        'source_folder': 'StorageFolder',
        'execution_trigger': 'ExecutionTrigger',
        'action_flow': 'ActionFlow',
        'target_folder': 'StorageFolder'
    }

    attribute_map = {
        'job_config_id': 'jobConfigId',
        'enabled': 'enabled',
        'active': 'active',
        'creation_date': 'creationDate',
        'mod_date': 'modDate',
        'name': 'name',
        'user_id': 'userId',
        'tenant_id': 'tenantId',
        'source_folder': 'sourceFolder',
        'execution_trigger': 'executionTrigger',
        'action_flow': 'actionFlow',
        'target_folder': 'targetFolder'
    }

    def __init__(self, job_config_id=None, enabled=None, active=None, creation_date=None, mod_date=None, name=None, user_id=None, tenant_id=None, source_folder=None, execution_trigger=None, action_flow=None, target_folder=None):  # noqa: E501
        """JobConfig - a model defined in Swagger"""  # noqa: E501

        self._job_config_id = None
        self._enabled = None
        self._active = None
        self._creation_date = None
        self._mod_date = None
        self._name = None
        self._user_id = None
        self._tenant_id = None
        self._source_folder = None
        self._execution_trigger = None
        self._action_flow = None
        self._target_folder = None
        self.discriminator = None

        self.job_config_id = job_config_id
        self.enabled = enabled
        if active is not None:
            self.active = active
        if creation_date is not None:
            self.creation_date = creation_date
        if mod_date is not None:
            self.mod_date = mod_date
        self.name = name
        self.user_id = user_id
        self.tenant_id = tenant_id
        if source_folder is not None:
            self.source_folder = source_folder
        if execution_trigger is not None:
            self.execution_trigger = execution_trigger
        if action_flow is not None:
            self.action_flow = action_flow
        if target_folder is not None:
            self.target_folder = target_folder

    @property
    def job_config_id(self):
        """Gets the job_config_id of this JobConfig.  # noqa: E501


        :return: The job_config_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._job_config_id

    @job_config_id.setter
    def job_config_id(self, job_config_id):
        """Sets the job_config_id of this JobConfig.


        :param job_config_id: The job_config_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if job_config_id is None:
            raise ValueError("Invalid value for `job_config_id`, must not be `None`")  # noqa: E501

        self._job_config_id = job_config_id

    @property
    def enabled(self):
        """Gets the enabled of this JobConfig.  # noqa: E501


        :return: The enabled of this JobConfig.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this JobConfig.


        :param enabled: The enabled of this JobConfig.  # noqa: E501
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def active(self):
        """Gets the active of this JobConfig.  # noqa: E501


        :return: The active of this JobConfig.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this JobConfig.


        :param active: The active of this JobConfig.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def creation_date(self):
        """Gets the creation_date of this JobConfig.  # noqa: E501


        :return: The creation_date of this JobConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this JobConfig.


        :param creation_date: The creation_date of this JobConfig.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def mod_date(self):
        """Gets the mod_date of this JobConfig.  # noqa: E501


        :return: The mod_date of this JobConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this JobConfig.


        :param mod_date: The mod_date of this JobConfig.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def name(self):
        """Gets the name of this JobConfig.  # noqa: E501


        :return: The name of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobConfig.


        :param name: The name of this JobConfig.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def user_id(self):
        """Gets the user_id of this JobConfig.  # noqa: E501


        :return: The user_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this JobConfig.


        :param user_id: The user_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this JobConfig.  # noqa: E501


        :return: The tenant_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this JobConfig.


        :param tenant_id: The tenant_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def source_folder(self):
        """Gets the source_folder of this JobConfig.  # noqa: E501


        :return: The source_folder of this JobConfig.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._source_folder

    @source_folder.setter
    def source_folder(self, source_folder):
        """Sets the source_folder of this JobConfig.


        :param source_folder: The source_folder of this JobConfig.  # noqa: E501
        :type: StorageFolder
        """

        self._source_folder = source_folder

    @property
    def execution_trigger(self):
        """Gets the execution_trigger of this JobConfig.  # noqa: E501


        :return: The execution_trigger of this JobConfig.  # noqa: E501
        :rtype: ExecutionTrigger
        """
        return self._execution_trigger

    @execution_trigger.setter
    def execution_trigger(self, execution_trigger):
        """Sets the execution_trigger of this JobConfig.


        :param execution_trigger: The execution_trigger of this JobConfig.  # noqa: E501
        :type: ExecutionTrigger
        """

        self._execution_trigger = execution_trigger

    @property
    def action_flow(self):
        """Gets the action_flow of this JobConfig.  # noqa: E501


        :return: The action_flow of this JobConfig.  # noqa: E501
        :rtype: ActionFlow
        """
        return self._action_flow

    @action_flow.setter
    def action_flow(self, action_flow):
        """Sets the action_flow of this JobConfig.


        :param action_flow: The action_flow of this JobConfig.  # noqa: E501
        :type: ActionFlow
        """

        self._action_flow = action_flow

    @property
    def target_folder(self):
        """Gets the target_folder of this JobConfig.  # noqa: E501


        :return: The target_folder of this JobConfig.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._target_folder

    @target_folder.setter
    def target_folder(self, target_folder):
        """Sets the target_folder of this JobConfig.


        :param target_folder: The target_folder of this JobConfig.  # noqa: E501
        :type: StorageFolder
        """

        self._target_folder = target_folder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
