# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.action_flow import ActionFlow  # noqa: F401,E501
from pdf4me.model.job_flow_plan import JobFlowPlan  # noqa: F401,E501


class JobFlow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_flow_id': 'str',
        'tenant_id': 'str',
        'subscription_id': 'str',
        'application_id': 'str',
        'name': 'str',
        'action_flow': 'ActionFlow',
        'job_flow_plan': 'JobFlowPlan',
        'creation_date': 'datetime'
    }

    attribute_map = {
        'job_flow_id': 'jobFlowId',
        'tenant_id': 'tenantId',
        'subscription_id': 'subscriptionId',
        'application_id': 'applicationId',
        'name': 'name',
        'action_flow': 'actionFlow',
        'job_flow_plan': 'jobFlowPlan',
        'creation_date': 'creationDate'
    }

    def __init__(self, job_flow_id=None, tenant_id=None, subscription_id=None, application_id=None, name=None, action_flow=None, job_flow_plan=None, creation_date=None):  # noqa: E501
        """JobFlow - a model defined in Swagger"""  # noqa: E501

        self._job_flow_id = None
        self._tenant_id = None
        self._subscription_id = None
        self._application_id = None
        self._name = None
        self._action_flow = None
        self._job_flow_plan = None
        self._creation_date = None
        self.discriminator = None

        if job_flow_id is not None:
            self.job_flow_id = job_flow_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if application_id is not None:
            self.application_id = application_id
        if name is not None:
            self.name = name
        if action_flow is not None:
            self.action_flow = action_flow
        if job_flow_plan is not None:
            self.job_flow_plan = job_flow_plan
        if creation_date is not None:
            self.creation_date = creation_date

    @property
    def job_flow_id(self):
        """Gets the job_flow_id of this JobFlow.  # noqa: E501


        :return: The job_flow_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._job_flow_id

    @job_flow_id.setter
    def job_flow_id(self, job_flow_id):
        """Sets the job_flow_id of this JobFlow.


        :param job_flow_id: The job_flow_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._job_flow_id = job_flow_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this JobFlow.  # noqa: E501


        :return: The tenant_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this JobFlow.


        :param tenant_id: The tenant_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this JobFlow.  # noqa: E501


        :return: The subscription_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this JobFlow.


        :param subscription_id: The subscription_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def application_id(self):
        """Gets the application_id of this JobFlow.  # noqa: E501


        :return: The application_id of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this JobFlow.


        :param application_id: The application_id of this JobFlow.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def name(self):
        """Gets the name of this JobFlow.  # noqa: E501


        :return: The name of this JobFlow.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobFlow.


        :param name: The name of this JobFlow.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def action_flow(self):
        """Gets the action_flow of this JobFlow.  # noqa: E501


        :return: The action_flow of this JobFlow.  # noqa: E501
        :rtype: ActionFlow
        """
        return self._action_flow

    @action_flow.setter
    def action_flow(self, action_flow):
        """Sets the action_flow of this JobFlow.


        :param action_flow: The action_flow of this JobFlow.  # noqa: E501
        :type: ActionFlow
        """

        self._action_flow = action_flow

    @property
    def job_flow_plan(self):
        """Gets the job_flow_plan of this JobFlow.  # noqa: E501


        :return: The job_flow_plan of this JobFlow.  # noqa: E501
        :rtype: JobFlowPlan
        """
        return self._job_flow_plan

    @job_flow_plan.setter
    def job_flow_plan(self, job_flow_plan):
        """Sets the job_flow_plan of this JobFlow.


        :param job_flow_plan: The job_flow_plan of this JobFlow.  # noqa: E501
        :type: JobFlowPlan
        """

        self._job_flow_plan = job_flow_plan

    @property
    def creation_date(self):
        """Gets the creation_date of this JobFlow.  # noqa: E501


        :return: The creation_date of this JobFlow.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this JobFlow.


        :param creation_date: The creation_date of this JobFlow.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobFlow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobFlow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
