# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OcrAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stapel': 'str',
        'businesss_card_reco': 'bool',
        'full_text_search': 'bool',
        'output_type': 'str'
    }

    attribute_map = {
        'stapel': 'stapel',
        'businesss_card_reco': 'businesssCardReco',
        'full_text_search': 'fullTextSearch',
        'output_type': 'outputType'
    }

    def __init__(self, stapel=None, businesss_card_reco=None, full_text_search=None, output_type=None):  # noqa: E501
        """OcrAction - a model defined in Swagger"""  # noqa: E501

        self._stapel = None
        self._businesss_card_reco = None
        self._full_text_search = None
        self._output_type = None
        self.discriminator = None

        if stapel is not None:
            self.stapel = stapel
        if businesss_card_reco is not None:
            self.businesss_card_reco = businesss_card_reco
        if full_text_search is not None:
            self.full_text_search = full_text_search
        if output_type is not None:
            self.output_type = output_type

    @property
    def stapel(self):
        """Gets the stapel of this OcrAction.  # noqa: E501


        :return: The stapel of this OcrAction.  # noqa: E501
        :rtype: str
        """
        return self._stapel

    @stapel.setter
    def stapel(self, stapel):
        """Sets the stapel of this OcrAction.


        :param stapel: The stapel of this OcrAction.  # noqa: E501
        :type: str
        """

        self._stapel = stapel

    @property
    def businesss_card_reco(self):
        """Gets the businesss_card_reco of this OcrAction.  # noqa: E501


        :return: The businesss_card_reco of this OcrAction.  # noqa: E501
        :rtype: bool
        """
        return self._businesss_card_reco

    @businesss_card_reco.setter
    def businesss_card_reco(self, businesss_card_reco):
        """Sets the businesss_card_reco of this OcrAction.


        :param businesss_card_reco: The businesss_card_reco of this OcrAction.  # noqa: E501
        :type: bool
        """

        self._businesss_card_reco = businesss_card_reco

    @property
    def full_text_search(self):
        """Gets the full_text_search of this OcrAction.  # noqa: E501


        :return: The full_text_search of this OcrAction.  # noqa: E501
        :rtype: bool
        """
        return self._full_text_search

    @full_text_search.setter
    def full_text_search(self, full_text_search):
        """Sets the full_text_search of this OcrAction.


        :param full_text_search: The full_text_search of this OcrAction.  # noqa: E501
        :type: bool
        """

        self._full_text_search = full_text_search

    @property
    def output_type(self):
        """Gets the output_type of this OcrAction.  # noqa: E501


        :return: The output_type of this OcrAction.  # noqa: E501
        :rtype: str
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        """Sets the output_type of this OcrAction.


        :param output_type: The output_type of this OcrAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "txt", "docx", "xlsx", "pptx", "pdfSearchable", "xml", "rtf", "rtt", "vcf", "json"]  # noqa: E501
        if output_type not in allowed_values:
            raise ValueError(
                "Invalid value for `output_type` ({0}), must be one of {1}"  # noqa: E501
                .format(output_type, allowed_values)
            )

        self._output_type = output_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OcrAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OcrAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
